@@ -1,6 +1,7 @@
-use crate::context::AppContext;
 use crate::error::AppResult;
+use crate::types::state::AppState;
 use crate::ui::AppBackend;
+use std::path::Path;
 use std::process::{Command, Stdio};
 
 use super::reload;
@@ -12,20 +13,22 @@ pub enum SubprocessCallMode {
     Capture,
 }
 
-pub fn current_filenames(context: &AppContext) -> Vec<&str> {
+pub fn current_files(app_state: &AppState) -> Vec<(&str, &Path)> {
     let mut result = Vec::new();
-    if let Some(curr_list) = context.tab_context_ref().curr_tab_ref().curr_list_ref() {
+    if let Some(curr_list) = app_state
+        .state
+        .tab_state_ref()
+        .curr_tab_ref()
+        .curr_list_ref()
+    {
         let mut i = 0;
-        curr_list
-            .iter_selected()
-            .map(|e| e.file_name())
-            .for_each(|file_name| {
-                result.push(file_name);
-                i += 1;
-            });
+        curr_list.iter_selected().for_each(|entry| {
+            result.push((entry.file_name(), entry.file_path()));
+            i += 1;
+        });
         if i == 0 {
             if let Some(entry) = curr_list.curr_entry_ref() {
-                result.push(entry.file_name());
+                result.push((entry.file_name(), entry.file_path()));
             }
         }
     }
@@ -33,36 +36,42 @@ pub fn current_filenames(context: &AppContext) -> Vec<&str> {
     result
 }
 
+fn current_dir(app_state: &AppState) -> &Path {
+    app_state.state.tab_state_ref().curr_tab_ref().get_cwd()
+}
+
 fn execute_sub_process(
-    context: &mut AppContext,
+    app_state: &mut AppState,
     words: &[String],
     mode: SubprocessCallMode,
 ) -> std::io::Result<()> {
-    let mut command = Command::new(words[0].clone());
+    let current_files = current_files(app_state);
+    let command_base = if current_files.len() == 1 {
+        let (file_name, file_path) = current_files[0];
+
+        words[0]
+            .replace("%s", file_name)
+            .replace("%p", &file_path.to_string_lossy())
+    } else {
+        words[0].clone()
+    };
+
+    let mut command = Command::new(command_base);
     for word in words.iter().skip(1) {
-        match (*word).as_str() {
+        match word.as_str() {
             "%s" => {
-                current_filenames(context).into_iter().for_each(|x| {
-                    command.arg(x);
-                });
+                for (file_name, _) in &current_files {
+                    command.arg(file_name);
+                }
             }
             "%p" => {
-                if let Some(curr_list) = context.tab_context_ref().curr_tab_ref().curr_list_ref() {
-                    let mut i = 0;
-                    curr_list
-                        .iter_selected()
-                        .map(|e| e.file_path())
-                        .for_each(|file_path| {
-                            command.arg(file_path);
-                            i += 1;
-                        });
-                    if i == 0 {
-                        if let Some(entry) = curr_list.curr_entry_ref() {
-                            command.arg(entry.file_path());
-                        }
-                    }
+                for (_, file_path) in &current_files {
+                    command.arg(file_path);
                 }
             }
+            "%d" => {
+                command.arg(current_dir(app_state));
+            }
             s => {
                 command.arg(s);
             }
@@ -78,13 +87,13 @@ fn execute_sub_process(
                     } else {
                         Err(std::io::Error::new(
                             std::io::ErrorKind::Other,
-                            format!("Command failed with {:?}", status),
+                            format!("Command failed with {}", status),
                         ))
                     }
                 }
                 Err(err) => Err(std::io::Error::new(
                     std::io::ErrorKind::Other,
-                    format!("Shell execution failed: {:?}", err),
+                    format!("Shell execution failed: {}", err),
                 )),
             }
         }
@@ -101,12 +110,13 @@ fn execute_sub_process(
                 .stderr(Stdio::piped())
                 .output()?;
             if output.status.code() == Some(0) {
-                context.last_stdout = Some(String::from_utf8_lossy(&output.stdout).to_string());
+                app_state.state.last_stdout =
+                    Some(String::from_utf8_lossy(&output.stdout).to_string());
                 Ok(())
             } else {
                 Err(std::io::Error::new(
                     std::io::ErrorKind::Other,
-                    format!("Command failed with {:?}", output.status),
+                    format!("Command failed with {}", output.status),
                 ))
             }
         }
@@ -115,7 +125,7 @@ fn execute_sub_process(
 
 /// Handler for Joshuto's `shell` and `spawn` commands.
 pub fn sub_process(
-    context: &mut AppContext,
+    app_state: &mut AppState,
     backend: &mut AppBackend,
     words: &[String],
     mode: SubprocessCallMode,
@@ -125,22 +135,25 @@ pub fn sub_process(
             // Joshuto needs to release the terminal when handing it over to some interactive
             // shell command and restore it afterwards
             backend.terminal_drop();
-            execute_sub_process(context, words, mode)?;
+            let res = execute_sub_process(app_state, words, mode);
             backend.terminal_restore()?;
-            let _ = reload::soft_reload_curr_tab(context);
-            context
+            let _ = reload::soft_reload_curr_tab(app_state);
+            res?;
+            app_state
+                .state
                 .message_queue_mut()
                 .push_info(format!("Finished: {}", words.join(" ")));
         }
         SubprocessCallMode::Spawn => {
-            execute_sub_process(context, words, mode)?;
-            context
+            execute_sub_process(app_state, words, mode)?;
+            app_state
+                .state
                 .message_queue_mut()
                 .push_info(format!("Spawned: {}", words.join(" ")));
         }
         SubprocessCallMode::Capture => {
-            execute_sub_process(context, words, mode)?;
-            let _ = reload::soft_reload_curr_tab(context);
+            execute_sub_process(app_state, words, mode)?;
+            let _ = reload::soft_reload_curr_tab(app_state);
         }
     };
     Ok(())
