@@ -4,29 +4,14 @@ use std::path::{Path, PathBuf};
 
 use walkdir::WalkDir;
 
-use crate::config::clean::app::display::dirlist::DirListDisplayOptions;
-use crate::config::clean::app::display::tab::TabDisplayOption;
-use crate::config::clean::app::display::DisplayOption;
-use crate::context::UiContext;
-use crate::fs::{JoshutoDirEntry, JoshutoDirList, JoshutoMetadata};
+use crate::fs::{DirListDisplayOptions, JoshutoDirEntry, JoshutoDirList, JoshutoMetadata};
+use crate::tab::TabDisplayOption;
+use crate::types::option::display::DisplayOption;
+use crate::types::state::UiState;
 
 pub trait DirectoryHistory {
     fn insert_entries(&mut self, entries: Vec<JoshutoDirList>);
-    fn create_or_soft_update(
-        &mut self,
-        path: &Path,
-        options: &DisplayOption,
-        tab_options: &TabDisplayOption,
-    ) -> io::Result<()>;
-    fn create_or_reload(
-        &mut self,
-        path: &Path,
-        options: &DisplayOption,
-        tab_options: &TabDisplayOption,
-    ) -> io::Result<()>;
     fn depreciate_all_entries(&mut self);
-
-    fn depreciate_entry(&mut self, path: &Path);
 }
 
 pub type JoshutoHistory = HashMap<PathBuf, JoshutoDirList>;
@@ -38,52 +23,9 @@ impl DirectoryHistory for JoshutoHistory {
         }
     }
 
-    fn create_or_soft_update(
-        &mut self,
-        path: &Path,
-        options: &DisplayOption,
-        tab_options: &TabDisplayOption,
-    ) -> io::Result<()> {
-        let (contains_key, need_update) = if let Some(dirlist) = self.get(path) {
-            (true, dirlist.need_update())
-        } else {
-            (false, true)
-        };
-        if need_update {
-            let dirlist = if contains_key {
-                create_dirlist_with_history(self, path, options, tab_options)?
-            } else {
-                JoshutoDirList::from_path(path.to_path_buf(), options, tab_options)?
-            };
-            self.insert(path.to_path_buf(), dirlist);
-        }
-        Ok(())
-    }
-
-    fn create_or_reload(
-        &mut self,
-        path: &Path,
-        options: &DisplayOption,
-        tab_options: &TabDisplayOption,
-    ) -> io::Result<()> {
-        let dirlist = if self.contains_key(path) {
-            create_dirlist_with_history(self, path, options, tab_options)?
-        } else {
-            JoshutoDirList::from_path(path.to_path_buf(), options, tab_options)?
-        };
-        self.insert(path.to_path_buf(), dirlist);
-        Ok(())
-    }
-
     fn depreciate_all_entries(&mut self) {
         self.iter_mut().for_each(|(_, v)| v.depreciate());
     }
-
-    fn depreciate_entry(&mut self, path: &Path) {
-        if let Some(v) = self.get_mut(path) {
-            v.depreciate();
-        }
-    }
 }
 
 fn get_index_of_value(arr: &[JoshutoDirEntry], val: &Path) -> Option<usize> {
@@ -227,7 +169,7 @@ where
 pub fn generate_entries_to_root(
     path: &Path,
     history: &JoshutoHistory,
-    ui_context: &UiContext,
+    ui_state: &UiState,
     display_options: &DisplayOption,
     tab_options: &TabDisplayOption,
 ) -> io::Result<Vec<JoshutoDirList>> {
@@ -240,7 +182,7 @@ pub fn generate_entries_to_root(
                 create_dirlist_with_history(history, curr, display_options, tab_options)?;
             if let Some(ancestor) = prev.as_ref() {
                 if let Some(i) = get_index_of_value(&new_dirlist.contents, ancestor) {
-                    new_dirlist.set_index(Some(i), ui_context, display_options);
+                    new_dirlist.set_index(Some(i), ui_state, display_options);
                 }
             }
             dirlists.push(new_dirlist);
@@ -252,7 +194,7 @@ pub fn generate_entries_to_root(
             )?;
             if let Some(ancestor) = prev.as_ref() {
                 if let Some(i) = get_index_of_value(&new_dirlist.contents, ancestor) {
-                    new_dirlist.set_index(Some(i), ui_context, display_options);
+                    new_dirlist.set_index(Some(i), ui_state, display_options);
                 }
             }
             dirlists.push(new_dirlist);
