@@ -1,12 +1,13 @@
-use ratatui::text::Span;
-use std::isize;
 use std::path::Path;
 
-use crate::config::clean::theme::tab::TabTheme;
-use crate::util::string::UnicodeTruncate;
-use crate::HOME_DIR;
+use ratatui::text::Span;
+
 use unicode_width::UnicodeWidthStr;
 
+use crate::config::theme::tab::TabTheme;
+use crate::utils::string::UnicodeTruncate;
+use crate::HOME_DIR;
+
 // This file provides stuff to factor a tab-line from a list of paths.
 //
 // The tab-line logic uses these basic cases:
@@ -234,11 +235,7 @@ fn factor_tab_bar_sequence(
     //##         (=> we need scrolling)
     //####################################################################
     let scroll_tags_width = config.inference.calc_scroll_tags_width(tab_num);
-    let scrollable_width = if scroll_tags_width > available_width {
-        0
-    } else {
-        available_width - scroll_tags_width
-    };
+    let scrollable_width = available_width.saturating_sub(scroll_tags_width);
 
     let carousel_labels = if all_labels_as_long[current_index].width()
         + config.inference.active_tab_extra_width
@@ -397,11 +394,7 @@ fn factor_tab_bar_sequence(
     tab_bar_elements.insert(0, TabBarElement::ScrollFrontPostfix);
     tab_bar_elements.insert(
         0,
-        TabBarElement::ScrollFront(if let Some(remains) = remaining_left {
-            remains
-        } else {
-            0
-        }),
+        TabBarElement::ScrollFront(remaining_left.unwrap_or_default()),
     );
     tab_bar_elements.insert(0, TabBarElement::ScrollFrontPrefix);
     // padding...
@@ -417,11 +410,7 @@ fn factor_tab_bar_sequence(
     // right scroll tag...
     tab_bar_elements.push(TabBarElement::ScrollBackPrefix);
     tab_bar_elements.push(TabBarElement::ScrollBack(
-        if let Some(remains) = remaining_right {
-            remains
-        } else {
-            0
-        },
+        remaining_right.unwrap_or_default(),
     ));
     tab_bar_elements.push(TabBarElement::ScrollBackPostfix);
 
@@ -526,8 +515,7 @@ pub fn factor_tab_bar_spans<'a>(
 
 #[cfg(test)]
 mod tests_facator_tab_bar_sequence {
-    use crate::config::clean::theme::tab::TabTheme;
-    use crate::config::raw::theme::tab::TabThemeRaw;
+    use crate::config::theme::{tab::TabTheme, tab_raw::TabThemeRaw};
 
     use super::{factor_tab_bar_sequence, TabBarElement, TabLabel};
 
