@@ -4,12 +4,12 @@ mod tui_dirlist_loading;
 mod tui_file_preview;
 mod tui_footer;
 mod tui_help;
+mod tui_io_tasks;
 mod tui_menu;
 mod tui_message;
 mod tui_prompt;
 mod tui_text;
 mod tui_topbar;
-mod tui_worker;
 
 pub use self::tui_dirlist::TuiDirList;
 pub use self::tui_dirlist_detailed::{trim_file_label, TuiDirListDetailed};
@@ -17,9 +17,9 @@ pub use self::tui_dirlist_loading::TuiDirListLoading;
 pub use self::tui_file_preview::TuiFilePreview;
 pub use self::tui_footer::TuiFooter;
 pub use self::tui_help::{get_keymap_table, TuiHelp};
+pub use self::tui_io_tasks::TuiIoTasks;
 pub use self::tui_menu::TuiMenu;
 pub use self::tui_message::TuiMessage;
 pub use self::tui_prompt::TuiPrompt;
 pub use self::tui_text::TuiMultilineText;
 pub use self::tui_topbar::TuiTopBar;
-pub use self::tui_worker::TuiWorker;
