@@ -5,15 +5,15 @@ use ratatui::layout::Rect;
 use ratatui::style::{Color, Modifier, Style};
 use ratatui::widgets::Widget;
 
-use crate::config::clean::app::display::line_mode::LineMode;
-use crate::config::clean::app::display::line_number::LineNumberStyle;
-use crate::config::clean::app::display::tab::TabDisplayOption;
-use crate::config::clean::app::display::DisplayOption;
-use crate::config::clean::app::AppConfig;
+use crate::config::app::AppConfig;
 use crate::fs::{FileType, JoshutoDirEntry, JoshutoDirList, LinkType};
-use crate::util::string::UnicodeTruncate;
-use crate::util::style;
-use crate::util::{format, unix};
+use crate::tab::TabDisplayOption;
+use crate::types::option::display::DisplayOption;
+use crate::types::option::line_mode::{LineMode, LineModeArgs, LineNumberStyle};
+use crate::utils::format::time_to_string;
+use crate::utils::string::UnicodeTruncate;
+use crate::utils::style;
+use crate::utils::{format, unix};
 use unicode_width::UnicodeWidthStr;
 
 use super::tui_dirlist::get_entry_icon;
@@ -47,7 +47,7 @@ impl<'a> TuiDirListDetailed<'a> {
     }
 }
 
-impl<'a> Widget for TuiDirListDetailed<'a> {
+impl Widget for TuiDirListDetailed<'_> {
     fn render(self, area: Rect, buf: &mut Buffer) {
         if area.width < 4 || area.height < 1 {
             return;
@@ -66,7 +66,7 @@ impl<'a> Widget for TuiDirListDetailed<'a> {
 
         let drawing_width = area.width as usize;
         let skip_dist = self.dirlist.first_index_for_viewport();
-        let line_num_style = self.display_options.line_nums();
+        let line_num_style = self.display_options.line_number_style;
         // Length (In chars) of the last entry's index on current page.
         // Using this to align all elements
         let max_index_length = (skip_dist
@@ -129,10 +129,31 @@ fn get_entry_size_string(entry: &JoshutoDirEntry) -> String {
             .directory_size()
             .map(|n| n.to_string())
             .unwrap_or_default(),
-        FileType::File => format::file_size_to_string(entry.metadata.len()),
+        _ => format::file_size_to_string(entry.metadata.len()),
     }
 }
 
+fn display_line_mode(mode: LineMode, entry: &JoshutoDirEntry) -> String {
+    let metadata = &entry.metadata;
+
+    mode.mode
+        .iter()
+        .take(mode.size)
+        .map(|arg| match arg {
+            LineModeArgs::Size => get_entry_size_string(entry),
+            LineModeArgs::ModifyTime => time_to_string(metadata.modified()),
+            LineModeArgs::AccessTime => time_to_string(metadata.accessed()),
+            LineModeArgs::User => unix::uid_to_string(metadata.uid).unwrap_or("unknown".into()),
+            LineModeArgs::Group => unix::gid_to_string(metadata.gid).unwrap_or("unknown".into()),
+            LineModeArgs::Permission => unix::mode_to_char_array(metadata.mode, metadata.file_type)
+                .iter()
+                .collect(),
+            LineModeArgs::Null => unreachable!(),
+        })
+        .collect::<Vec<String>>()
+        .join(" ")
+}
+
 #[allow(clippy::too_many_arguments)]
 fn print_entry(
     config: &AppConfig,
@@ -152,7 +173,7 @@ fn print_entry(
     let name = entry.file_name();
     #[cfg(feature = "devicons")]
     let label = {
-        if config.display_options_ref().show_icons() {
+        if config.display_options.show_icons {
             let icon = get_entry_icon(config, entry.file_name(), entry.ext(), &entry.metadata);
             format!("{icon} {name}")
         } else {
@@ -164,22 +185,8 @@ fn print_entry(
     let label = name.to_string();
 
     let left_label_original = label;
-    let right_label_original = format!(
-        " {}{} ",
-        symlink_string,
-        linemode
-            .iter_names()
-            .map(|f| match f.0 {
-                "size" => get_entry_size_string(entry),
-                "mtime" => format::mtime_to_string(entry.metadata.modified()),
-                "user" => unix::uid_to_string(entry.metadata.uid).unwrap_or("unknown".into()),
-                "group" => unix::gid_to_string(entry.metadata.gid).unwrap_or("unknown".into()),
-                "perm" => unix::mode_to_string(entry.metadata.mode),
-                _ => unreachable!(),
-            })
-            .collect::<Vec<_>>()
-            .join(" ")
-    );
+    let right_label_original =
+        format!(" {}{} ", symlink_string, display_line_mode(linemode, entry));
 
     // draw prefix first
     let prefix_width = prefix.width();
@@ -188,11 +195,8 @@ fn print_entry(
 
     // factor left_label and right_label
     let drawing_width = drawing_width - prefix_width;
-    let (left_label, right_label) = factor_labels_for_entry(
-        &left_label_original,
-        right_label_original.as_str(),
-        drawing_width,
-    );
+    let (left_label, right_label) =
+        factor_labels_for_entry(left_label_original, right_label_original, drawing_width);
 
     // Draw labels
     buf.set_stringn(x, y, left_label, drawing_width, style);
@@ -205,11 +209,11 @@ fn print_entry(
     );
 }
 
-fn factor_labels_for_entry<'a>(
-    left_label_original: &'a str,
-    right_label_original: &'a str,
+fn factor_labels_for_entry(
+    left_label_original: String,
+    right_label_original: String,
     drawing_width: usize,
-) -> (String, &'a str) {
+) -> (String, String) {
     let left_label_original_width = left_label_original.width();
     let right_label_original_width = right_label_original.width();
 
@@ -217,21 +221,25 @@ fn factor_labels_for_entry<'a>(
     let width_remainder = left_width_remainder - left_label_original_width as i32;
 
     if drawing_width == 0 {
-        ("".to_string(), "")
+        ("".into(), "".into())
     } else if width_remainder >= 0 {
         (left_label_original.to_string(), right_label_original)
     } else if left_width_remainder < MIN_LEFT_LABEL_WIDTH {
         (
             if left_label_original.width() as i32 <= left_width_remainder {
-                trim_file_label(left_label_original, drawing_width)
+                trim_file_label(&left_label_original, drawing_width)
             } else {
                 left_label_original.to_string()
             },
-            "",
+            if let Some(width) = (drawing_width - MIN_LEFT_LABEL_WIDTH as usize).checked_sub(3) {
+                right_label_original.chars().take(width).collect::<String>() + " .."
+            } else {
+                "".into()
+            },
         )
     } else {
         (
-            trim_file_label(left_label_original, left_width_remainder as usize),
+            trim_file_label(&left_label_original, left_width_remainder as usize),
             right_label_original,
         )
     }
@@ -278,8 +286,8 @@ mod test_factor_labels {
         let left = "foo.ext";
         let right = "right";
         assert_eq!(
-            ("".to_string(), ""),
-            factor_labels_for_entry(left, right, 0)
+            ("".to_string(), "".to_string()),
+            factor_labels_for_entry(left.into(), right.into(), 0)
         );
     }
 
@@ -288,8 +296,8 @@ mod test_factor_labels {
         let left = "foo.ext";
         let right = "right";
         assert_eq!(
-            (left.to_string(), right),
-            factor_labels_for_entry(left, right, 20)
+            (left.to_string(), right.to_string()),
+            factor_labels_for_entry(left.into(), right.into(), 20)
         );
     }
 
@@ -298,8 +306,8 @@ mod test_factor_labels {
         let left = "foo.ext";
         let right = "right";
         assert_eq!(
-            (left.to_string(), right),
-            factor_labels_for_entry(left, right, 12)
+            (left.to_string(), right.to_string()),
+            factor_labels_for_entry(left.into(), right.into(), 12)
         );
     }
 
@@ -309,8 +317,8 @@ mod test_factor_labels {
         let right = "right";
         assert!(left.chars().count() as i32 == MIN_LEFT_LABEL_WIDTH);
         assert_eq!(
-            ("foobarbazfo.ext".to_string(), ""),
-            factor_labels_for_entry(left, right, MIN_LEFT_LABEL_WIDTH as usize)
+            ("foobarbazfo.ext".to_string(), "".to_string()),
+            factor_labels_for_entry(left.into(), right.into(), MIN_LEFT_LABEL_WIDTH as usize)
         );
     }
 
@@ -320,10 +328,10 @@ mod test_factor_labels {
         let right = "right";
         assert!(left.chars().count() as i32 > MIN_LEFT_LABEL_WIDTH + right.chars().count() as i32);
         assert_eq!(
-            ("foobarbazf….ext".to_string(), right),
+            ("foobarbazf….ext".to_string(), right.to_string()),
             factor_labels_for_entry(
-                left,
-                right,
+                left.into(),
+                right.into(),
                 MIN_LEFT_LABEL_WIDTH as usize + right.chars().count()
             )
         );
@@ -337,8 +345,8 @@ mod test_factor_labels {
         let right = "right";
         assert!(left.chars().count() as i32 > MIN_LEFT_LABEL_WIDTH);
         assert_eq!(
-            ("foooooobaaaaaaarbaaaa…".to_string(), right),
-            factor_labels_for_entry(left, right, left.chars().count())
+            ("foooooobaaaaaaarbaaaa…".to_string(), right.to_string()),
+            factor_labels_for_entry(left.into(), right.into(), left.chars().count())
         );
     }
 }
