@@ -4,10 +4,10 @@ use ratatui::style::{Color, Style};
 use ratatui::text::{Line, Span};
 use ratatui::widgets::{Paragraph, Widget};
 
-use crate::config::clean::app::display::tab::TabDisplayOption;
 use crate::fs::{JoshutoDirList, LinkType};
-use crate::util::format;
-use crate::util::unix;
+use crate::tab::TabDisplayOption;
+use crate::utils::format;
+use crate::utils::unix;
 use crate::{THEME_T, TIMEZONE_STR};
 
 pub struct TuiFooter<'a> {
@@ -24,11 +24,8 @@ impl<'a> TuiFooter<'a> {
     }
 }
 
-impl<'a> Widget for TuiFooter<'a> {
+impl Widget for TuiFooter<'_> {
     fn render(self, area: Rect, buf: &mut Buffer) {
-        #[cfg(unix)]
-        use std::os::unix::fs::PermissionsExt;
-
         let visual_mode_style = Style::default().fg(Color::Black).bg(Color::LightRed);
         let mode_style = Style::default().fg(Color::Cyan);
 
@@ -47,12 +44,15 @@ impl<'a> Widget for TuiFooter<'a> {
             Some(i) if i < self.dirlist.len() => {
                 let entry = &self.dirlist.contents[i];
 
-                let mode_str = unix::mode_to_string(entry.metadata.permissions_ref().mode());
+                let mode_str: String =
+                    unix::mode_to_char_array(entry.metadata.mode, entry.metadata.file_type)
+                        .iter()
+                        .collect();
 
                 let user_str = unix::uid_to_string(entry.metadata.uid).unwrap_or("unknown".into());
                 let group_str = unix::gid_to_string(entry.metadata.gid).unwrap_or("unknown".into());
 
-                let mtime_str = format::mtime_to_string(entry.metadata.modified());
+                let mtime_str = format::time_to_string(entry.metadata.modified());
                 let size_str = format::file_size_to_string(entry.metadata.len());
 
                 let path = self.dirlist.file_path();
@@ -92,8 +92,8 @@ impl<'a> Widget for TuiFooter<'a> {
                     ),
                     Span::styled(
                         match self.tab_options.dirlist_options_ref(&path.to_path_buf()) {
-                            Some(opt) if !opt.filter_context_ref().is_none() => {
-                                format!("filter:{} ", opt.filter_context_ref())
+                            Some(opt) if !opt.filter_state_ref().is_none() => {
+                                format!("filter:{} ", opt.filter_state_ref())
                             }
                             _ => "".to_owned(),
                         },
