@@ -6,22 +6,22 @@ use ratatui::widgets::{Paragraph, Widget};
 
 use tab_list_builder::factor_tab_bar_spans;
 
-use crate::context::AppContext;
+use crate::types::state::AppState;
 use crate::ui::tab_list_builder;
 use crate::THEME_T;
 use crate::{HOSTNAME, USERNAME};
 
 pub struct TuiTopBar<'a> {
-    pub context: &'a AppContext,
+    pub app_state: &'a AppState,
 }
 
 impl<'a> TuiTopBar<'a> {
-    pub fn new(context: &'a AppContext) -> Self {
-        Self { context }
+    pub fn new(app_state: &'a AppState) -> Self {
+        Self { app_state }
     }
 }
 
-impl<'a> Widget for TuiTopBar<'a> {
+impl Widget for TuiTopBar<'_> {
     fn render(self, area: Rect, buf: &mut Buffer) {
         let name_width = USERNAME.as_str().len() + HOSTNAME.as_str().len() + 2;
 
@@ -42,14 +42,14 @@ impl<'a> Widget for TuiTopBar<'a> {
 
         let available_tab_width = area.width as usize - name_width;
         let mut paths = Vec::new();
-        let tabs = self.context.tab_context_ref().tab_refs_in_order();
+        let tabs = self.app_state.state.tab_state_ref().tab_refs_in_order();
         for tab in tabs {
-            paths.push(tab.cwd());
+            paths.push(tab.get_cwd());
         }
         let tab_bar_spans = factor_tab_bar_spans(
             available_tab_width,
             &paths,
-            self.context.tab_context_ref().index,
+            self.app_state.state.tab_state_ref().index,
             &THEME_T.tabs,
         );
         top_bar_spans.extend(tab_bar_spans);
